from arekit.common.labels.base import Label


class OpinionBelongsTo(Label):
    pass


class OpinionRelatesTo(Label):
    pass


class NegEffectFrom(Label):
    pass


class NegStateFrom(Label):
    pass


class PosEffectFrom(Label):
    pass


class PosAuthorFrom(Label):
    pass


class NegAuthorFrom(Label):
    pass


class PosStateFrom(Label):
    pass


class NegativeTo(Label):
    pass


class PositiveTo(Label):
    pass


class AlternativeName(Label):
    pass


class StateBelongsTo(Label):
    pass


class OriginsFrom(Label):
    pass
